Che cos’è OiRA | OiRA

Temi

# Che cos’è OiRA

## È la prima volta che utilizzi OiRA?

Di seguito trovi una breve introduzione alla valutazione dei rischi e una descrizione di come OiRA può aiutarti a gestirla.

## Che cos’è la valutazione dei rischi?

La valutazione dei rischi costituisce la base per una gestione efficace della sicurezza e della salute ed è essenziale per ridurre gli incidenti sul lavoro e le malattie professionali. Se attuata correttamente, può migliorare la sicurezza e la salute sul luogo di lavoro e le prestazioni dell’impresa in generale.

In Europa la sicurezza e la salute dei lavoratori sono tutelate mediante la valutazione e la gestione dei rischi sul lavoro. I datori di lavoro sono tenuti per legge a garantire la sicurezza e la salute dei lavoratori sotto ogni aspetto collegato al lavoro, nonché a eseguire una valutazione dei rischi. Ciascuna impresa deve pertanto effettuare una valutazione dei rischi e redigere un piano d’azione. Per poter eseguire un’efficace valutazione dei rischi sul luogo di lavoro, tutti i soggetti coinvolti devono comprendere chiaramente:

- il contesto e i concetti giuridici;
- la procedura applicata per valutare i rischi;
- il ruolo che spetta ai principali soggetti coinvolti in tale procedimento.

I lavoratori e/o i loro rappresentanti hanno il diritto di essere consultati sulle misure da attuare e di partecipare alla valutazione dei rischi.

Maggiori informazioni sulla valutazione dei rischi e sulla partecipazione dei lavoratori e/o dei loro rappresentanti al procedimento di valutazione dei rischi sono disponibili sul sito web del progetto OiRA.

## Che cos’è OiRA?

OiRA significa «valutazione interattiva online dei rischi». È un’applicazione basata sul web che consente di eseguire una valutazione dei rischi per la sicurezza e la salute presenti sul proprio luogo di lavoro.

## A chi è destinato OiRA?

OiRA può essere utilizzato da chiunque intenda valutare i rischi per la sicurezza e la salute eventualmente presenti sul proprio luogo di lavoro.

Tuttavia, è stato concepito in modo tale da risultare particolarmente utile per le imprese più piccole. OiRA è stato sviluppato specificamente per aiutare tali imprese a valutare i rischi sul lavoro e a redigere una valutazione dei rischi documentata, compreso un piano d’azione commisurato alle esigenze dell’impresa.

## Che cosa devo fare?

È necessario completare i vari passaggi previsti dalla procedura di valutazione dei rischi OiRA:

- Preparazione: alcuni strumenti contengono domande sul profilo che consentono di personalizzare lo strumento in base alle specificità dell’impresa. Quando rispondi alle domande sul profilo, lo strumento si adatterà alla tua situazione specifica e ti mostrerà i moduli pertinenti.

- Coinvolgimento: ogni valutazione dei rischi dovrebbe essere effettuata con il coinvolgimento attivo dei lavoratori. Lo strumento consente di stampare l’intero testo della valutazione dei rischi o alcune sue parti, allo scopo di informare i lavoratori e ricevere i loro riscontri.

- Individuazione dei rischi: OiRA mostrerà una serie di potenziali pericoli o problemi per la sicurezza e la salute che potrebbero essere presenti sul tuo luogo di lavoro. Rispondendo alle affermazioni/domande con un «sì» o un «no» indicherai se tali pericoli o problemi sono o meno presenti. Puoi anche decidere di non rispondere a una domanda e di lasciarla in sospeso, per rispondere in un momento successivo.

- Valutazione: alcuni strumenti chiedono di mettere in ordine di priorità i rischi individuati. A tal fine esistono varie modalità, a seconda delle decisioni adottate dai nostri partner OiRA/dagli sviluppatori nazionali dello strumento e del loro approccio specifico. Alcuni strumenti stabiliscono l’ordine di priorità dei rischi in maniera automatica, in background, ma è comunque possibile non tenerne conto.

- Piano d’azione: per ciascun rischio individuato lo strumento chiede di decidere una o più misure per eliminare o ridurre il rischio in questione. La maggior parte degli strumenti ne suggerisce alcune, ma è sempre possibile inserire le proprie misure.

- Relazione: documentare la valutazione dei rischi è un obbligo di legge. Nella sezione dedicata alle relazioni, troverai una serie di relazioni che ti aiuteranno a tenere traccia delle valutazioni dei rischi e a dare seguito alle azioni/misure che hai deciso di attuare per eliminare o ridurre i rischi individuati.

## Quanto tempo è richiesto?

È impossibile dire in generale quanto tempo ci vuole per fare una valutazione, perché gli strumenti variano a seconda del settore e del paese.

Tuttavia, puoi dedicare a una valutazione il tempo che hai a disposizione in un dato momento e riprenderla successivamente, quando ti è più comodo, partendo dal punto in cui l’avevi lasciata.

## Perché devo registrarmi?

La prima cosa che ti sarà chiesto di fare quando inizierai la tua prima valutazione dei rischi è creare un account OiRA - si tratta di un procedimento semplice e rapido.

La registrazione ti permette di accedere facilmente in qualsiasi momento per proseguire le valutazioni precedenti o avviarne di nuove.

Se sei un utente registrato, hai anche la possibilità di ottenere in qualsiasi momento una valutazione dei rischi stampata, accurata e aggiornata.

## Ho bisogno di una preparazione?

Non hai bisogno di alcuna preparazione specifica per cominciare a utilizzare lo strumento; tuttavia, dovresti prenderti un po’ di tempo per stabilire chi eseguirà la valutazione dei rischi e come coinvolgere i lavoratori in tale procedimento.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More